@@ -1,9 +1,9 @@
 package Text::Table::More;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-06'; # DATE
+our $DATE = '2021-08-07'; # DATE
 our $DIST = 'Text-Table-More'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use 5.010001;
 use strict;
@@ -607,7 +607,7 @@ Text::Table::More - Generate text table with simple interface and many options
 
 =head1 VERSION
 
-This document describes version 0.014 of Text::Table::More (from Perl distribution Text-Table-More), released on 2021-04-06.
+This document describes version 0.015 of Text::Table::More (from Perl distribution Text-Table-More), released on 2021-08-07.
 
 =head1 SYNOPSIS
 
@@ -774,15 +774,11 @@ Value: yes.
 
 =item * can_color
 
-Can produce colored table.
-
-Value: no.
+Value: yes.
 
 =item * can_color_theme
 
-Allow choosing colors from a named set of palettes.
-
-Value: no.
+Value: yes.
 
 =item * can_colspan
 
@@ -790,57 +786,39 @@ Value: yes.
 
 =item * can_customize_border
 
-Let user customize border character in some way, e.g. selecting from several available borders, disable border.
-
 Value: yes.
 
 =item * can_halign
 
-Provide a way for user to specify horizontal alignment (leftE<sol>middleE<sol>right) of cells.
-
 Value: yes.
 
 =item * can_halign_individual_cell
 
-Provide a way for user to specify different horizontal alignment (leftE<sol>middleE<sol>right) for individual cells.
-
 Value: yes.
 
 =item * can_halign_individual_column
 
-Provide a way for user to specify different horizontal alignment (leftE<sol>middleE<sol>right) for individual columns.
-
 Value: yes.
 
 =item * can_halign_individual_row
 
-Provide a way for user to specify different horizontal alignment (leftE<sol>middleE<sol>right) for individual rows.
-
 Value: yes.
 
 =item * can_hpad
 
-Provide a way for user to specify horizontal padding of cells.
-
-Value: no.
+Value: yes.
 
 =item * can_hpad_individual_cell
 
-Provide a way for user to specify different horizontal padding of individual cells.
-
-Value: no.
+Value: yes.
 
 =item * can_hpad_individual_column
 
-Provide a way for user to specify different horizontal padding of individual columns.
-
-Value: no.
+Value: yes.
 
 =item * can_hpad_individual_row
 
-Provide a way for user to specify different horizontal padding of individual rows.
-
-Value: no.
+Value: yes.
 
 =item * can_rowspan
 
@@ -848,86 +826,58 @@ Value: yes.
 
 =item * can_set_cell_height
 
-Allow setting height of rows.
-
-Value: no.
+Value: yes.
 
 =item * can_set_cell_height_of_individual_row
 
-Allow setting height of individual rows.
-
-Value: no.
+Value: yes.
 
 =item * can_set_cell_width
 
-Allow setting height of rows.
-
-Value: no.
+Value: yes.
 
 =item * can_set_cell_width_of_individual_column
 
-Allow setting height of individual rows.
-
-Value: no.
+Value: yes.
 
 =item * can_use_box_character
 
-Can use terminal box-drawing character when drawing border.
-
 Value: yes.
 
 =item * can_valign
 
-Provide a way for user to specify vertical alignment (topE<sol>middleE<sol>bottom) of cells.
-
 Value: yes.
 
 =item * can_valign_individual_cell
 
-Provide a way for user to specify different vertical alignment (topE<sol>middleE<sol>bottom) for individual cells.
-
 Value: yes.
 
 =item * can_valign_individual_column
 
-Provide a way for user to specify different vertical alignment (topE<sol>middleE<sol>bottom) for individual columns.
-
 Value: yes.
 
 =item * can_valign_individual_row
 
-Provide a way for user to specify different vertical alignment (topE<sol>middleE<sol>bottom) for individual rows.
-
 Value: yes.
 
 =item * can_vpad
 
-Provide a way for user to specify vertical padding of cells.
-
-Value: no.
+Value: yes.
 
 =item * can_vpad_individual_cell
 
-Provide a way for user to specify different vertical padding of individual cells.
-
-Value: no.
+Value: yes.
 
 =item * can_vpad_individual_column
 
-Provide a way for user to specify different vertical padding of individual columns.
-
-Value: no.
+Value: yes.
 
 =item * can_vpad_individual_row
 
-Provide a way for user to specify different vertical padding of individual rows.
-
-Value: no.
+Value: yes.
 
 =item * speed
 
-Subjective speed rating, relative to other text table modules.
-
 Value: "slow".
 
 =back
@@ -1102,7 +1052,7 @@ Source repository is at L<https://github.com/perlancar/perl-Text-Table-More>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Text-Table-More/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-Table-More>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -1129,7 +1079,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by perlancar@cpan.org.
+This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
